@@ -17,7 +17,7 @@ describe 'gnocchi::client' do
 
   context 'on Debian platforms' do
     let :facts do
-      { :osfamily => 'Debian' }
+      @default_facts.merge({ :osfamily => 'Debian' })
     end
 
     it_configures 'gnocchi client'
@@ -25,7 +25,7 @@ describe 'gnocchi::client' do
 
   context 'on RedHat platforms' do
     let :facts do
-      { :osfamily => 'RedHat' }
+      @default_facts.merge({ :osfamily => 'RedHat' })
     end
 
     it_configures 'gnocchi client'
