@@ -21,8 +21,10 @@ describe 'gnocchi' do
 
   context 'on Debian platforms' do
     let :facts do
-      { :osfamily        => 'Debian',
-        :operatingsystem => 'Debian' }
+      @default_facts.merge({
+        :osfamily        => 'Debian',
+        :operatingsystem => 'Debian',
+      })
     end
 
     let :platform_params do
@@ -34,7 +36,7 @@ describe 'gnocchi' do
 
   context 'on RedHat platforms' do
     let :facts do
-      { :osfamily => 'RedHat' }
+      @default_facts.merge({ :osfamily => 'RedHat' })
     end
 
     let :platform_params do
